---
title: <span class="badge object-type-enum"></span> BarGaugeSizing
---
# <span class="badge object-type-enum"></span> BarGaugeSizing

Allows for the bar gauge size to be set explicitly

## Definition

```python
class BarGaugeSizing(enum.StrEnum):
    """
    Allows for the bar gauge size to be set explicitly
    """

    AUTO = "auto"
    MANUAL = "manual"
```
